==> hs-gconf-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/gconf-0.12.0/register.sh <==
#!/bin/sh
echo 'name: gconf
version: 0.12.0
id: gconf-0.12.0-c451fc9d91632288d09ad57054c69c5c

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: GConf is a configuration database system for storing application
             preferences. It supports default or mandatory settings set by the
             administrator, and changes to the database are instantly applied to all
             running applications. It is written for the GNOME desktop but doesn'\''t
             require it.
category: System
author: Duncan Coutts
exposed: True
exposed-modules: System.Gnome.GConf System.Gnome.GConf.GConfClient
hidden-modules: System.Gnome.GConf.GConfValue
                System.Gnome.GConf.Types System.Gnome.GConf.Signals
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/gconf-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/gconf-0.12.0
              /usr/local/lib
hs-libraries: HSgconf-0.12.0
extra-libraries: gconf-2 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gconf/2
              /usr/local/include/orbit-2.0 /usr/local/include/glib-2.0
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         glib-0.12.0-8144dd6b871a3f77547c0bef30f04b3e
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/gconf-0.12.0/html/gconf.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/gconf-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gconf-0.12.1.tbz: lib/ghc-7.0.4/cabal/gconf-0.12.1/register.sh <==
#!/bin/sh
echo 'name: gconf
version: 0.12.1
id: gconf-0.12.1-b5ac3c255d6b36f1d0dca88a9b5bbb8a

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: GConf is a configuration database system for storing application
             preferences. It supports default or mandatory settings set by the
             administrator, and changes to the database are instantly applied to all
             running applications. It is written for the GNOME desktop but doesn'\''t
             require it.
category: System
author: Duncan Coutts
exposed: True
exposed-modules: System.Gnome.GConf System.Gnome.GConf.GConfClient
hidden-modules: System.Gnome.GConf.GConfValue
                System.Gnome.GConf.Types System.Gnome.GConf.Signals
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/gconf-0.12.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/gconf-0.12.1
              /usr/local/lib
hs-libraries: HSgconf-0.12.1
extra-libraries: gconf-2 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gconf/2
              /usr/local/include/orbit-2.0 /usr/local/include/glib-2.0
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/gconf-0.12.1/html/gconf.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/gconf-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
